@@ -3,15 +3,14 @@ import os
 
 sys.path.append(os.path.dirname(__file__))
 
-from jhsp.sann.bin import config
-from jhsp.tools import collating_words
+from jhsp.tools.collating_words import CW
+from jhsp.preprocessing.codingdata import Codingdata
 
 # 导入sann模块的所有包
 import configparser
 
 
 
-
 # 定义SANN类
 class Sann():
     def __init__(self,input_path,task_name_list):
@@ -47,7 +46,12 @@ class Sann():
 # 在调用时实例化，因为要传入一个工作目录
 
 
-CW = collating_words.CW
+
+
+
+
+
+
 
 
 
